import typing
import collections.abc
import typing_extensions

class RawBlendFileReader:
    """Return a file handle to the raw blend file data (abstracting compressed formats)."""

def main(): ...
def read_blend_rend_chunk(filepath): ...



import typing
import collections.abc
import typing_extensions

def copy(execution_context: int | str | None = None, undo: bool | None = None):
    """Copy the material settings and nodes

    :type execution_context: int | str | None
    :type undo: bool | None
    """

def new(execution_context: int | str | None = None, undo: bool | None = None):
    """Add a new material

    :type execution_context: int | str | None
    :type undo: bool | None
    """

def paste(execution_context: int | str | None = None, undo: bool | None = None):
    """Paste the material settings and nodes

    :type execution_context: int | str | None
    :type undo: bool | None
    """
